@@ -1,4 +1,4 @@
-require 'fog/core/model'
+require "fog/core/model"
 
 module Fog
   module Google
@@ -6,14 +6,14 @@ module Fog
       ##
       # A metricDescriptor defines the name, label keys, and data type of a particular metric.
       #
-      # @see https://developers.google.com/cloud-monitoring/v2beta1/metricDescriptors
+      # @see https://cloud.google.com/monitoring/v2beta2/metricDescriptors#resource
       class MetricDescriptor < Fog::Model
         identity :name
 
         attribute :description
         attribute :labels
         attribute :project
-        attribute :type_descriptor, :aliases => 'typeDescriptor'
+        attribute :type_descriptor, :aliases => "typeDescriptor"
       end
     end
   end
